if IsAddOnLoaded("Titan") and not IsAddOnLoaded("FuBar") then
	-- Do not load if Titanbar is loaded
	return
end

local beql = LibStub("AceAddon-3.0"):GetAddon("beql")
local L = LibStub("AceLocale-3.0"):GetLocale("beql")
beqlfu = Rock:NewAddon("beqlFu", "LibFuBarPlugin-3.0", "LibRockDB-1.0")
local GameTooltip = GameTooltip

beqlfu:SetFuBarOption('hasIcon', true)
beqlfu:SetFuBarOption('iconPath', "Interface\\Icons\\INV_Letter_03")
beqlfu:SetFuBarOption('title', "bEQL")
beqlfu:SetFuBarOption('name', "beql")
beqlfu:SetFuBarOption('revision', beql.revision)
beqlfu:SetFuBarOption('cannotDetachTooltip', true)
beqlfu:SetFuBarOption('overrideMenu', true)
beqlfu:SetFuBarOption('independentProfile', false)
beqlfu:SetFuBarOption('hideWithoutStandby', true)

-- this db is only a dummy, real data will saved in beql.db.profile.fubar
-- this dummy is needed to access text and icon functions
beqlfu:SetDatabase("beqlFuDB")

local function round(input, places)
	if not places then
			places = 0
	end
	if type(input) == "number" and type(places) == "number" then
			local pow = 1
			for i = 1, ceil(places) do
					pow = pow * 10
			end
			return floor(input * pow + 0.5) / pow
	end
end

function beqlfu:OnInitialize()
    local _,questEntries = GetNumQuestLogEntries()
--	beqlfu.db = LibStub("AceDB-3.0"):New("fubar")
--	beql.db:RegisterNamespace("fubar")
	beqlfu:SetFuBarText(questEntries.."/25")
end

local firstDone

function beqlfu:OnEnable()
	if not firstDone then
		beqlfu:UpdateFuBarPluginSettings()
		firstDone = true
	end
	print("enable beqlfu")
end

local beqlfu_hook_OnDragStop

function beqlfu:UpdateFuBarPlugin()

	if not beqlfu_hook_OnDragStop then
		-- add function to minimap icon dragging, to get the icon position
		local MinimapButton = _G[beqlfu:GetFrame():GetName() ..  "MinimapButton"]
		if MinimapButton and type(MinimapButton:GetScript("OnDragStop")) == 'function' then
			MinimapButton:HookScript("OnDragStop", function() 
				beql.db.profile.fubar.MinimapPosition = round(beqlfu.db.profile.minimapPosition) 
			end)
			beqlfu_hook_OnDragStop = true
		end
	end

end

function beqlfu:UpdateFuBarTooltip()
	if not beql.db.profile.fubar.ShowTooltip then
		return
	end
	
	if beqlfu:IsFuBarMinimapAttached() then
		GameTooltip:SetOwner(_G[beqlfu:GetFrame():GetName() .. "MinimapButton"],"ANCHOR_BOTTOMLEFT",30,0)
	else
		GameTooltip:SetOwner(beqlfu:GetFrame(),"ANCHOR_BOTTOM",0,0)
	end
	
	local _,questEntries = GetNumQuestLogEntries()
	local _, numfinished = beqlQ:GetNumQuests()
	beqlfu:SetFuBarText(questEntries.."/25")
	
	-- build Gametooltip
	
	-- title
	GameTooltip:AddLine(beqlfu:GetName())
	GameTooltip:AddLine(" ") -- spacer
	
	-- num quests
	GameTooltip:AddDoubleLine(L["|cffffffffQuests|r"],questEntries)
	
	-- num watched quests
	GameTooltip:AddDoubleLine(L["|cffff8000Tracked Quests|r"],GetNumQuestWatches())
	
	-- num completed quests
	GameTooltip:AddDoubleLine(L["|cff00d000Completed Quests|r"], numfinished)
	GameTooltip:AddLine(" ") -- spacer
	
	-- tooltip hint
	GameTooltip:AddLine(L["|cffeda55fClick|r to open Quest Log and |cffeda55fShift+Click|r to open Waterfall config"],0,1,0,true)
	
	GameTooltip:Show()
end

function beqlfu:UpdateFuBarPluginSettings()
	local fubaroptions = beql.db.profile.fubar
	if not firstDone then
		beqlfu:SetFuBarOption('defaultMinimapPosition', fubaroptions.MinimapPosition)
		return
	end
	
	beqlfu:Hide()
	beqlfu.db.profile.minimapPosition = fubaroptions.MinimapPosition
	beqlfu:SetFuBarOption('defaultPosition', fubaroptions.FubarPosition)
	
	if not beql.db.profile.fubar.HidePlugin then
		beqlfu:Show()
		-- manage position
		if (beqlfu:IsFuBarMinimapAttached() and fubaroptions.FubarPosition ~= 'MINIMAP' ) 
			or ( not beqlfu:IsFuBarMinimapAttached() and fubaroptions.FubarPosition == 'MINIMAP' ) 
				then
					beqlfu:ToggleFuBarMinimapAttached()
		end
		-- manage text
		if (fubaroptions.ShowText == true and not beqlfu:IsFuBarTextShown()) 
			or (fubaroptions.ShowText == false and beqlfu:IsFuBarTextShown())
				then
					beqlfu:ToggleFuBarTextShown()
		end
		-- manage colored text
		if (fubaroptions.ShowColoredText == true and not beqlfu:IsFuBarTextColored()) 
			or (fubaroptions.ShowColoredText == false and beqlfu:IsFuBarTextColored())
				then
					beqlfu:ToggleFuBarTextColored()
		end
		-- manage Icon
		if (fubaroptions.ShowIcon == true and not beqlfu:IsFuBarIconShown()) 
			or (fubaroptions.ShowIcon == false and beqlfu:IsFuBarIconShown())
				then
					beqlfu:ToggleFuBarIconShown()
		end
		
		local _,questEntries = GetNumQuestLogEntries()
		beqlfu:SetFuBarText(questEntries.."/25")
	end
end

function beqlfu:OpenMenu()
	-- show fubar config instead of a menu
	InterfaceOptionsFrame_OpenToCategory(beql3.optionsFrames["fubar"])
end

function beqlfu:OnFuBarClick()
	if IsShiftKeyDown() then
		InterfaceOptionsFrame_OpenToCategory(beql3.optionsFrames["main"])
	else
		ToggleFrame(QuestLogFrame);
	end
end
